# netsky

not skynet, obviously

## getting started

`pip install netsky`

Create the `~/.netsky/.env` file with valid Marvin environment variables.

### verify installation

`netsky` should now be installed as a CLI tool:

```python
(venv) cody@dkdcsot netsky % netsky

 Usage: netsky [OPTIONS] COMMAND [ARGS]...

╭─ Options ─────────────────────────────────────────────────╮
│ --version                     Show version.               │
│ --install-completion          Install completion for the  │
│                               current shell.              │
│ --show-completion             Show completion for the     │
│                               current shell, to copy it   │
│                               or customize the            │
│                               installation.               │
│ --help                        Show this message and exit. │
╰───────────────────────────────────────────────────────────╯
╭─ Commands ────────────────────────────────────────────────╮
│ ai                            ai                          │
│ test                          test                        │
╰───────────────────────────────────────────────────────────╯
```

Confirm commands work:

```python
(venv) cody@dkdcsot netsky % netsky test
testing.ai: done...
```

And invoke advanced ai commands:

```python
(venv) cody@dkdcsot netsky % netsky ai
netsky.ai:
access to: netsky.ai
```

## demo

to be linked

## next steps

world domination!

